@@ -12,9 +12,9 @@ from __future__ import unicode_literals
 
 from .literal import Literal
 from .statement import Statement
-from .value import Value, URI, BNode
+from .value import Value, URI, BNode, QuotedTriple
 from .valuefactory import ValueFactory
 from .utils import parse_term
 
 __all__ = ['BNode', 'Literal', 'Statement', 'URI',
-    'Value', 'ValueFactory', 'parse_term']
+           'Value', 'ValueFactory', 'parse_term', "QuotedTriple"]
